import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Street with large mansion'

	if 'Wanda' in the_player.visited:
		the_player.directions = ['Suburb Junction','Wanda\'s house']
	else:
		the_player.directions = ['Suburb Junction','Mansion']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
	else:
		the_player.visited.append(the_player.location)

		print "Dog barking gets louder and you can"
		print "tell the sound is coming from a large"
		print "house at the end of the street."

	while True:
		action = prompt.standard(the_player)

		if action == "suburb junction" or action == "junction":
			return 'Suburb Junction'
		elif 'house' in action or 'mansion' in action:
			return 'Wandas House'
		else:
			custom_error.errortype(3)



import sys
import splashscreen
import custom_error

def enter(the_player):

	splashscreen.outro()

	print "\nAs you set sail you feel a peace, finally."
	print "You observe Welton as it gets further away from"
	print "you. You don't know where you'll end up"
	print "but as long as Wanda\'s with you,"
	print "you feel it's gonna be alright."
	print " \nTHE END"

	custom_error.errortype(4)
	
	splashscreen.score_board(the_player)
	
	custom_error.errortype(4)
	
	exit(1)



import random
import prompt
import custom_error
import death
import score

def enter(the_player):

	the_player.location = 'Old Building (second floor)'
	the_player.directions = ['Old Building (first floor)']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		charlie_greets = [
		'looking good','missed you',"haven't seen you for a while",
		'nice ass','nice outside?']

		print "You come back to %s." % the_player.location
		print "'Hey there %s, %s!' Charlie screams." % (the_player.name, random.choice(charlie_greets))

		if 'Wanda' in the_player.visited:
			print "Good day to you too, Wanda. Sorry about Dave."

	else:
		the_player.visited.append(the_player.location)

		print "You slowly and carefully climb to second"
		print "floor. You see the source of light now."
		print "It's a small candle under the window."
		print "You see sleeping bag near it and"
		print "empty food cans around."
		print "Someone lives here, evidently."

		custom_error.errortype(4)

		if 'Wanda' in the_player.visited:
			print "Old grey man appears out of nowhere."
			print "'Wanda, wh-wh-what you doin here?' he says."
			print "'I came here to get our stuff' she replies."
			print "\n'Me and Dave were here few days earlier"
			print "and we had a plan to get out of Welton.'"
			print "Old man looks into the ground, his eyes"
			print "fixed on his feet."

			custom_error.errortype(4)

			print "'Listen... sorry if you feel offended, I just"
			print "wanted to keep Dave around, in case something..."
			print "I don't know... changed.'"
			print "\nWanda: 'It's okay Charlie. Don't sweat it..."
			print "We ended it. Just few moments ago. I know"
			print "he wouldn't want a life like that'"
			print "Charlie: 'Oh.. OK. You can stay for today"
			print "if you need the rest':"

			while True:
				rest = str(raw_input("Y/N > ")).lower()
				the_player.visited.append('charlie sleepover')

				if rest == "y":
					the_player.hitpoints = the_player.max_hitpoints
					print "You feel good after good rest. You have %.1f hitpoints now." % the_player.hitpoints
					break
				elif rest == "n":
					break
				else:
					custom_error.errortype(5)

			custom_error.errortype(4)
			print "Charlie: 'OK, your stuff is down in the lobby."
			print "I think you're gonna need this.'"
			print "He handles you a flashlight."

			if 'flashlight' in the_player.inventory.keys():
				pass
			else:
				the_player.inventory['flashlight'] = 1



		else:
			charlie_check = random.randint(0,1)
			if charlie_check == 0:
				print "You feel something hard landing on your head"
				print "and almost lose conscience."
				charlie_hit = random.uniform(0.1,1.0)
				the_player.hitpoints = the_player.hitpoints - charlie_hit

				if the_player.hitpoints <= 0:
					death.type(6)
				else:
					print "You lose %.1f hitpoints." % charlie_hit
					custom_error.errortype(4)

			elif charlie_check == 1:
				print "You see something approaching fast in"
				print "your peripheral vision."
				print "You manage to roll a feet away and stand"
				print "on your feet."

				score.calculate(the_player, 'charlie hit')

			print "You see old grey man in front of you."
			print "He was definitely hiding in the dark corner"
			print "across the candle."
			print "'Howdy there, I'm awfully sorry for that!"
			print "I thought it was Dave, he snapped that"
			print "rope last week and I had to fight him.'"

			end_conversation = False

			while end_conversation == False:
				print "\n'Heard some noise, is he allright?'\n"
				print "1. Yes"
				print "2. No"
				
				answer = prompt.conversation()

				if answer == 1:
					print "'Good, good, he's a good boy."
					print "He used to work for me in my restaurant."
					print "I know he's different now...."
					print "But I keep him around, as a warning"
					print "and to keep me safe."
					print "I know it's strange, don't judge me.'"
					
					break

				elif answer == 2:

					while end_conversation == False:
		
						print "'No? What did you do to him?!'"
						print "1. The rope snapped, I just defended myself."
						print "2. I killed that fucker!"
					
						answer2 = prompt.conversation()

						if answer2 == 1:
							print "'Oh...' Looks like old man is about to cry."
							print "I kind of got attached to him, even when"
							print "he became different, y'know..."
							print "Nevermind...'"
							
							end_conversation = True

						elif answer2 == 2:
							print "'What!!! You... I'm gonna fuckin ~#^@#$...'"
							print "Old man pulls a huge shotgun out of his"
							print "coat."
							death.type(8, the_player)

						else:
							custom_error.errortype(1)

				else:
					custom_error.errortype(1)

			print "'Hey there, my name's Charlie. What's yours?'"

			custom_error.errortype(4)

			print "'%s' you mumble." % the_player.name
			print "\nYou hear Charlie's story, about his pizza place"
			print "and life he had before."
			print "You talked for a while and he offered you to stay"
			print "for the night: 'I saw a pack of 'em from the window."
			print "Wouldn't be safe for you to wander around at night.'\n"
			print "You agree and wake up late next day."

			custom_error.errortype(4)

			hp_to_heal = the_player.max_hitpoints - the_player.hitpoints
			the_player.hitpoints = the_player.hitpoints + hp_to_heal
			the_player.visited.append('charlie sleepover')

			print "You gain %.1f hitpoints from good night sleep.\n" % hp_to_heal
			print "'Listen, %s, by the way you wouldn't have some candy" % the_player.name
			print "on you or something?'"
			print "I might have a flashlight to trade...'"


	while True:
		action = prompt.standard(the_player)

		if "first floor" in action:
			return 'Old Building (first floor)'
		elif "chocolate" in action and 'Wanda' in the_player.visited:
			print "Charlie: 'No thanks.'"
		elif action == "chocolate" and 'flashlight' in the_player.inventory.keys() or action == "chocolate bar" and 'flashlight' in the_player.inventory.keys():
			print "Sorry, I don't have anything else to trade."
		elif action == "chocolate" or action == "chocolate bar" and the_player.inventory['chocolate bar'] >= 1:
			the_player.inventory['chocolate bar'] = the_player.inventory['chocolate bar'] - 1
			the_player.inventory['flashlight'] = 1
			print "Charlie: 'Great! Here you go, you might have a good use for it!'"
			print "He gives you working flashlight"
			score.calculate(the_player, 'flashlight')
		elif action == "chocolate" or action == "chocolate bar" and the_player.inventory['chocolate bar'] == 0:
			print "You don't have any chocolate bar to give to Charlie."
		else:
			custom_error.errortype(3)


import random
import prompt
import score
import custom_error

def enter(the_player):

	the_player.location = 'Kitchen'

	the_player.directions = ['Hallway of the house']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "You're back at %s." % the_player.location
		print "There are several shelves and four cupboards"
		print "above the sink."

	else:
		the_player.visited.append(the_player.location)

		print "You step into a kitchen. It looks like"
		print "it's been raided."

		if 'Wanda' in the_player.visited:
			print "Wanda: 'We've been here before with"
			print "Dave to get some food.'"
		else:
			pass
		
		print "There are several shelves and four cupboards"
		print "above the sink."

	cupboard = 1

	while True:
		
		action = prompt. standard(the_player)

		if 'house' in action or 'out' in action or 'hallway' in action:
			return 'House with pirate flag'
		elif 'cupboard' in action:
			print "You search one of the cupboards..."
			cupboard = cupboard + 1
			if cupboard == 4 and 'gun' in the_player.inventory.keys():
				print "You find some bullets for the gun!"
				the_player.inventory['gun'] = the_player.inventory['gun'] + 5
				score.calculate(the_player,'bullets')
			else:
				print "...and nothing. Maybe try looking in the other one?"
		elif 'shelves' in action or 'shelf' in action:
			print "Nothing in the shelves."
		else:
			custom_error.errortype(3)



import death
import apartment
import curling_street
import junction
import march_street
import twentysecond_street
import foreman_ave
import harrington_river
import marina
import old_building
import old_building_1f
import old_building_2f
import suburbs
import suburb_1
import suburb_2
import suburb_3
import suburb_4
import suburb_5
import suburb_6
import pirate_house
import basement
import kitchen
import suburb_junction
import cherry_tree
import small_houses
import very_long_street
import wandas_house
import motor_shop
import warehouse
import maintenance_room
import restroom
import wandas_boat
import ending

class Engine(object):

	def __init__(self, the_player, start_map):
		self.the_player = the_player
		self.start_map = start_map

		
	def move(self):
		
		if self.the_player.age >= 100:
			death.type(1)
		elif self.the_player.age <= 3:
			death.type(2)
		else:
			pass

		current_map = Maps.map_dict.get(self.start_map)
		
		while True:
			
			get_next_map = current_map.enter(self.the_player)
			current_map = Maps.map_dict.get(get_next_map)

			if get_next_map == None:
				pass
			else:
				pass


class Maps(object):

	map_dict = {
	'Apartment': apartment,
	'Curling Street': curling_street,
	'Junction': junction,
	'March Street': march_street,
	'22nd Street': twentysecond_street,
	'Foreman Ave': foreman_ave,
	'Harrington River': harrington_river,
	'Old Building': old_building,
	'Old Building (first floor)': old_building_1f,
	'Old Building (second floor)': old_building_2f,
	'Suburbs': suburbs,
	'Suburb 1': suburb_1,
	'Suburb 2': suburb_2,
	'Suburb 3': suburb_3,
	'Suburb 4': suburb_4,
	'Suburb 5': suburb_5,
	'Suburb 6': suburb_6,
	'Suburb Junction': suburb_junction,
	'Small houses': small_houses,
	'House with pirate flag': pirate_house,
	'Basement': basement,
	'Kitchen': kitchen,
	'Cherry trees': cherry_tree,
	'A very long street': very_long_street,
	'Wandas House': wandas_house,
	'Motor Shop': motor_shop,
	'Warehouse': warehouse,
	'Maintenance room': maintenance_room,
	'Restroom': restroom,
	'Marina': marina,
	'Wanda\'s boat': wandas_boat,
	'Ending': ending

	}

	def visited(self):
		visited_maps = map_dict.keys()


	

	





	



import sys
import custom_error
import splashscreen

def type(death_id, the_player):

		death_dict = {
			1: "\nYou're so old you barely survived the first wave of zombie attack. Just as you get out of the bed you feel pain chest. Seconds later you fall to the ground and die",
			2: "\n'Baba.. da-ba'. You're just a baby unable to do anything really. You starve to death and die.",
			3: "\nYou reached zero/negative hitpoints. You die.",
			4: "\nYou're an old fart. You get heart attack from push ups and die seconds later.",
			5: "\nYou exhaust yourself and later a zombie approaches you. Your lack of strength is unable to deal with it. You're dead now... and sort of alive but the game is over now.",
			6: "\nYou reached zero/negative hitpoints and got killed by your enemy.",
			7: "\nYou get bitten by zombie and eventually turn dead. You die.",
			8: "\nLast thing you see is a barrel of shotgun and sparks in slow motion. 'Fucker' you hear old man mumbling.",
			9: "\nYou feel a pinch on your finger as you turn cylinders on the lock again. Seconds later you stop breathing and you die.",
			10: "\n'What a stupid answer.' You think to yourself as you feel the bullet coming through you.",
			11: "\nAs you keep going the cracking sound gets louder. Eventually the bridge collapses and you lose conscience when you fall into river, drowning to death.",
			12: "\nYou lose balance for a little while and you slip. A lone glass shrapnel hanging from the window impales you."
			}

		get_death_type = death_dict.get(death_id)
		print get_death_type
		print "Your score is %d." % the_player.score

		custom_error.errortype(4)
		splashscreen.score_board(the_player)
		custom_error.errortype(4)
		exit(1)


# -*- coding: utf-8 -*-

import ast
import operator
import custom_error

def intro():
	print """
                      :::!~!!!!!:.
                  .xUHWH!! !!?M88WHX:.
                .X*#M@$!!  !X!M$$$$$$WWx:.
               :!!!!!!?H! :!$!$$$$$$$$$$8X:
              !!~  ~:~!! :~!$!#$$$$$$$$$$8X:
             :!~::!H!<   ~.U$X!?R$$$$$$$$MM!
             ~!~!!!!~~ .:XW$$$U!!?$$$$$$RMM!
               !:~~~ .:!M"T#$$$$WX??#MRRMMM!
               ~?WuxiW*`   `"#$$$$8!!!!??!!!
             :X- M$$$$       `"T#$T~!8$WUXU~
            :%`  ~#$$$m:        ~!~ ?$$$$$$
          :!`.-   ~T$$$$8xx.  .xWW- ~""##*"
.....   -~~:<` !    ~?T#$$@@W@*?$$      /`
W$@@M!!! .!~~ !!     .:XUW$W!~ `"~:    :
#"~~`.:x%`!!  !H:   !WM$$$$Ti.: .!WUn+!`
:::~:!!`:X~ .: ?H.!u "$$$B$$$!W:U!T$$M~
.~~   :X@!.-~   ?@WTWo("*$$$W$TH$! `
Wi.~!X$?!-~    : ?$$$B$Wu("**$RM!
$R@i.~~ !     :   ~$$$$$B$$en:``
?MXT@Wx.~    :     ~"##*$$$$M~
"""

def outro():
	print"""
            ^^                   @@@@@@@@@
       ^^       ^^            @@@@@@@@@@@@@@@
                            @@@@@@@@@@@@@@@@@@              ^^
                           @@@@@@@@@@@@@@@@@@@@
 ~~~~ ~~ ~~~~~ ~~~~~~~~ ~~ &&&&&&&&&&&&&&&&&&&& ~~~~~~~ ~~~~~~~~~~~ ~~~
 ~         ~~   ~  ~       ~~~~~~~~~~~~~~~~~~~~ ~       ~~     ~~ ~
   ~      ~~      ~~ ~~ ~~  ~~~~~~~~~~~~~ ~~~~  ~     ~~~    ~ ~~~  ~ ~~
   ~  ~~     ~         ~      ~~~~~~  ~~ ~~~       ~~ ~ ~~  ~~ ~
 ~  ~       ~ ~      ~           ~~ ~~~~~~  ~      ~~  ~             ~~
       ~             ~        ~      ~      ~~   ~             ~ 
	"""

def new_game():
	print "Winter has been long in the little town of"
	print "Welton in Kentucky."
	print "Weird stuff has been happening since the summer"
	print "but the full outbreak hasn't happened until October."
	print "Government's been awfully quiet about the whole affair"
	print "and then it was too late to do anything."
	print "Everything happened quickly. Your family is gone now"
	print "and you have been surviving on snow water and ramen"
	print "for past three weeks."
	print "Now it's time to go out..."


def killed_enemies(the_player):

	print "\n--- Killed enemies ---"

	for enemy,number in the_player.killed.items():
		print enemy, ':', number

def score_board(the_player):
	
	ordinary_guy = {'Ordinary Guy': 100}

	score_file = open('scoreboard.txt', 'r')

	if len(score_file.read()) == 0:
		score_file.close()
		score_file = open('scoreboard.txt', 'w')
		score_file.write(str(ordinary_guy))
		score_file.close()
	else:
		score_file.close()
		pass

	score_file = open('scoreboard.txt', 'r')

	scores = ast.literal_eval(score_file.readline())
	score_file.close()
	sorted_scores = sorted(scores.iteritems(), key = operator.itemgetter(1), reverse = True)
	previous_hi_score_tuple = sorted_scores[0]
	previous_hi_score = previous_hi_score_tuple[1]
	get_highest_score(the_player.score, previous_hi_score)

	score_file = open('scoreboard.txt', 'r')

	if len(score_file.read()) == 0:
		score_file.close()
		scores = {}
		scores[the_player.name] = the_player.score
		score_file = open('scoreboard.txt', 'w')
		score_file.write(str(scores))
		score_file.close()
		
	else:
		score_file = open('scoreboard.txt', 'r')
		scores = ast.literal_eval(score_file.readline())
		score_file.close()

	scores[the_player.name] = the_player.score
	score_file = open('scoreboard.txt', 'w')
	score_file.write(str(scores))
	score_file.close()

	sorted_scores = sorted(scores.iteritems(), key = operator.itemgetter(1), reverse = True)



	print "\n"
	print "*" * 80
	print "***** Scoreboard *****"
	print "*" * 80
	
	num = 1

	for name, score in sorted_scores:
		print str(num) + '.', name, " ....... ", score,"points"
		num = num + 1

	custom_error.errortype(4)
	killed_enemies(the_player)

def get_highest_score(score, previous_hi_score):

	if score > previous_hi_score:
		print chr(27) + "[2J"
		intro()
		print "!!! NEW HIGH SCORE !!!"
		print "!!!%d points!!!" % score
		print "Congratulations."
		custom_error.errortype(4)

	elif score >= previous_hi_score:
		print chr(27) + "[2J"
		print "!!! TIE HIGH SCORE !!!"
		print "You have %d, same as previous winner!" % score
		print "Congrats."
		custom_error.errortype(4)
		
		
	else:
		pass







	



import prompt
import death
import custom_error

def enter(the_player):

	the_player.location = 'Harrington River'
	the_player.directions = ['March Street','Marina','Bridge']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "You're back at %s." % the_player.location

	else:
		the_player.visited.append(the_player.location)
		print "The March Street ends abruptly with a large"
		print "parking lot in front of Harrington River."
		print "There is a wooden bridge that overarches the river"
		print "so you can keep going."
		print "A narrow stairwell-like path leads to river's"
		print "edge where small marina is located along"
		print "with couple of boats."

	while True:

		action = prompt.standard(the_player)

		if "bridge" in action:
			print "You step on the bridge and hear loud"
			print "cracking beneath your feet."

			bridge_prompt = raw_input("Continue? Y/N > ").lower()

			if bridge_prompt == "y":
				death.type(11, the_player)
			else:
				pass

		elif 'stairs' in action or 'path' in action or 'marina' in action:
			return 'Marina'
		elif action == "march street":
			return 'March Street'
		else:
			custom_error.errortype(3)





import sys
from zombieadventure import custom_error
from zombieadventure import player
from zombieadventure import handler
from zombieadventure import prompt
from zombieadventure import splashscreen
from zombieadventure import game
from zombieadventure import death

def splash_screen():
	print chr(27) + "[2J"
	splashscreen.intro()
	print "*" * 80
	print "***** Welcome to ZOMBIE ADVENTURE ******"
	print "***  version 1.0.1 - comatory, 2014  ***"
	print "*" * 80
	print "Select option:"
	print "1. Start a new game"
	print "2. Load existing game"
	print "3. Quit"

	while True:
		action = prompt.menu()

		if action == 1:
			create_player = player.CreateNewPlayer()
			create_player_args = create_player.generate()
			the_player = player.Player(*create_player_args)

			if the_player.male == True:
				gender = "man"
			else:
				gender = "woman"

			print "\nYour name is %s and you're %d old." % (the_player.name, the_player.age)
			print "You're a %s. Your maximum hitpoints are %.1f." % (gender, the_player.hitpoints)

			print "\n1. Continue to game"
			print "2. Back to main menu"
			action = prompt.menu()

			
			if action == 1:

				if the_player.age <= 3:
					death.type(2, the_player)
				elif the_player.age >= 141:
					death.type(1, the_player)
				else:
					pass
	

				print chr(27) + "[2J"

				splashscreen.new_game()
				custom_error.errortype(4)

				prompt.game_help()
				custom_error.errortype(4)
				
				a_game = game.Engine(the_player, 'Apartment')
				a_game.move()

			elif action == 2:
				handler.load()
			else:
				custom_error.errortype(3)
				custom_error.errortype(2)
				splash_screen()
				# a_game = game.Engine()
				# a_game.launch_game(the_player)
		elif action == 2:
			handler.load()
		elif action == 3:
			exit(1)
		else:
			custom_error.errortype(0)


splash_screen()




import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Street with small houses'
	the_player.directions = ['Suburb Junction','A very long street']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
	else:
		the_player.visited.append(the_player.location)

		print "You come to street that has a lot"
		print "of small houses on both sides."
		print "It's uncanny how similar they are."
		print "There's a long street coming up ahead, Junction"
		print "behind you."

	while True:
		action = prompt.standard(the_player)

		if action == "suburb junction" or action == "junction":
			return 'Suburb Junction'
		elif action == "a very long street" or 'long' in action:
			return 'A very long street'
		else:
			custom_error.errortype(3)



import random

def errortype(error_id):

	if error_id == 0:
		print "\nI do not understand\n"
	elif error_id == 1:
		print "\nPut down numbers only\n"
	elif error_id == 2:
		raw_input("\nPress any key to start over\n")
	elif error_id == 3:
		 print random.choice(["Wrong input","I do not understand this","Does not compute","Try something else"])
	elif error_id == 4:
		raw_input("\nPress ENTER key to continue\n")
	elif error_id == 5:
		print "\nPlease type in 'Y' or 'N' only.\n"
	else:
		pass 


import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Street with a tree'
	the_player.directions = ['Shorter street','Suburb Junction']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
		print "The tree is still standing there"
		print "so nothing's changed."

	else:
		the_player.visited.append(the_player.location)

		print "You come to another street, again it's"
		print "very suburbish but you take a note"
		print "of an oak tree on side of the road."
		print "This street ends with a left turn."


	while True:
		action = prompt.standard(the_player)

		if action == "shorter street":
			return 'Suburb 4'
		elif action == "suburb junction" or action == "junction":
			return 'Suburb Junction'
		elif 'tree' in action:
			print "You come to the tree and see W + D carved into it."
		else:
			custom_error.errortype(3)



import random
import sys
import copy
import glob
import os.path
import custom_error
import prompt
import game

class Player(object):

	def __init__(self, name, age, male,
				inventory, max_hitpoints, hitpoints, 
				location, visited, score, directions,
				killed):

		self.name = name
		self.age = age
		self.male = male
		self.inventory = inventory
		self.max_hitpoints = max_hitpoints
		self.hitpoints = hitpoints
		self.location = location
		self.visited = visited
		self.score = score
		self.directions = directions
		self.killed = killed
	
class CreateNewPlayer(object):

	def generate(self):
		print chr(27) + "[2J"
		print "-" * 80
		print "Character creation"
		print "-" * 80


		try:
			check_name = self.check_for_name(str(raw_input("Type down your name > ")))
		except ValueError:
			custom_error.errortype(3)
			self.generate()

		name = copy.deepcopy(check_name)

		try:
			age = int(raw_input("Put down your age in numbers > "))
		except ValueError:
			custom_error.errortype(1)
			custom_error.errortype(2)
			self.generate()


		if age <= 0:
			print "Number must be larger than zero."
			custom_error.errortype(2)
			self.generate()
		else:
			pass

		male = True
		sex = str(raw_input("Are you a male or female? M/F > ")).lower()

		if sex == "m":
			male = True
		elif sex == "f":
			male = False
		else:
			print "Please type either 'M' or 'F'"
			custom_error.errortype(2)
			self.generate()

		if male:
			male_hp_bonus = 1.6
			
			if age < 3:
				hitpoints = random.randint(1,3) * male_hp_bonus
			elif age < 5:
				hitpoints = random.randint(8, 10) * male_hp_bonus
			elif age < 12:
				hitpoints = random.randint(10, 13) * male_hp_bonus
			elif age < 17:
				hitpoints = random.randint(16, 22) * male_hp_bonus
			elif age < 26:
				hitpoints = random.randint(25,32) * male_hp_bonus
			elif age < 33:
				hitpoints = random.randint(25,30) * male_hp_bonus
			elif age < 48:
				hitpoints = random.randint(27,29) * male_hp_bonus
			else:
				hitpoints = random.randint(16,22) * male_hp_bonus
		
		else:
			female_hp_bonus = 1.2


			if age < 3:
				hitpoints = random.randint(1,3) * female_hp_bonus
			elif age < 5:
				hitpoints = random.randint(8, 10) * female_hp_bonus
			elif age < 12:
				hitpoints = random.randint(10, 13) * female_hp_bonus
			elif age < 17:
				hitpoints = random.randint(16, 22) * female_hp_bonus
			elif age < 26:
				hitpoints = random.randint(25,32) * female_hp_bonus
			elif age < 33:
				hitpoints = random.randint(25,30) * female_hp_bonus
			elif age < 48:
				hitpoints = random.randint(27,29) * female_hp_bonus
			else:
				hitpoints = random.randint(16,22) * female_hp_bonus

		
		max_hitpoints = copy.deepcopy(hitpoints)
			

		return name, age, male, {}, max_hitpoints, hitpoints, 'apartment', [], 0, [], {}

	def check_for_name(self, name):

		saved_games = glob.glob('*.sav')

		save_file = [name + '.sav']

		if save_file[0] in saved_games:
			custom_error.errortype(6)
			custom_error.errortype(2)
			self.generate()
		else:
			return name





import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Row of houses'
	the_player.directions = ['Longer street','Suburb Junction']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
	else:
		the_player.visited.append(the_player.location)

		print "Just another street with rows of houses."
		print "This street ends with a right turn."


	while True:
		action = prompt.standard(the_player)

		if action == "longer street":
			return 'Suburb 3'
		elif action == "suburb junction" or 'junction' in action:
			return 'Suburb Junction'
		else:
			custom_error.errortype(3)



import custom_error
import prompt

def enter(the_player):

	the_player.location = 'Restroom'
	the_player.directions = ['Maintenance room']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "At restroom again."

	else:
		the_player.visited.append(the_player.location)

		print "You're in very little room with toilet"
		print "and sink in it. It is pretty crammed in"
		print "here."

	if 'broom' in the_player.inventory.keys():
		print "The door behind you lead back to %s." % the_player.directions[0]

	elif 'broom' not in the_player.inventory.keys():
		print "There's an old broom with steel handle"
		print "leaning on the wall."


	while True:
		

		action = prompt.standard(the_player)

		if action == "maintenance room" or action == "maintenance" or 'out' in action:
			return 'Maintenance room'
		elif "broom" in action:
			if 'broom' not in the_player.inventory.keys():
				print "You take the broom, it looks like it might"
				print "be useful for something."

				the_player.inventory['broom'] = 1
			else:
				print "You already have the broom."
		elif 'toilet' in action:
			print "You don't feel like going."
		else:
			custom_error.errortype(3)


import random
import sys

class Enemy(object):

	def __init__(self, enemy_name, enemy_hp, enemy_attack):
		self.enemy_name = enemy_name
		self.enemy_hp = enemy_hp
		self.enemy_attack = enemy_attack

	
class SpawnEnemy(object):

	def __init__(self, the_player, fetch_enemy_name):
		self.the_player = the_player
		self.fetch_enemy_name = fetch_enemy_name

	def player_penalty(self, the_player):

		if self.the_player.age < 3:
			penalty = 1.0
		elif self.the_player.age < 5:
			penalty = 1.3
		elif self.the_player.age < 12:
			penalty = 1.6
		elif self.the_player.age < 17:
			penalty = 2.0
		elif self.the_player.age < 26:
			penalty = 2.4
		elif self.the_player.age < 33:
			penalty = 2.7
		elif self.the_player.age < 48:
			penalty = 2.0
		elif self.the_player.age < 60:
			penalty = 1.6
		else:
			penalty = 1.0

		return penalty


	def enemy_type(self, fetch_enemy_name):

		enemy_table = [
		('child zombie', 5, 2),
		('Dave', 11, 3),
		('zombie male', 9, 4),
		('zombie overlord', 100, 20),
		('infected dog', 3, 4),
		('decomposed old man', 2, 1),
		('decomposed old woman', 1, 1),
		('teethless zombie', 1, 0),
		('zombie captain', 65, 13, 7),
		('zombie with missing arm', 5, 2)
		]

		get_index = [i for i in enemy_table if fetch_enemy_name in i]
		return get_index[0] if enemy_table else None				
		


	def generate(self, the_player, fetch_enemy_name):
		penalty = self.player_penalty(the_player)
		created_enemy = self.enemy_type(self.fetch_enemy_name)
		
		fetch_enemy_name = created_enemy[0]
		enemy_hp = created_enemy[1] * penalty
		enemy_attack = created_enemy[2] * penalty

		return fetch_enemy_name, enemy_hp, enemy_attack

	def generate_random(self, the_player):

		random_enemy_list = [
		'child zombie',
		'zombie male',
		'infected dog',
		'decomposed old man',
		'decomposed old woman',
		'teethless zombie',
		'zombie with missing arm'
		]

		penalty = self.player_penalty(the_player)
		pick_random_enemy = random.choice(random_enemy_list)
		random_enemy = self.enemy_type(pick_random_enemy)

		fetch_enemy_name = random_enemy[0]
		enemy_hp = random_enemy[1] * penalty
		enemy_attack = random_enemy[2] * penalty

		return fetch_enemy_name, enemy_hp, enemy_attack


	





import prompt
import custom_error

def enter(the_player):

	the_player.location = 'A very long street'
	the_player.directions = ['Suburbs','Street with small houses']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
	else:
		the_player.visited.append(the_player.location)

		print "Nothing special about this street"
		print "except that it's really long."
		print "When you get to the end you"
		print "get a familiar sight in front of you."

	while True:
		action = prompt.standard(the_player)

		if action == "suburbs":
			return 'Suburbs'
		elif action == "street with small houses" or 'small houses' in action:
			return 'Street with small houses'
		else:
			custom_error.errortype(3)



import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Junction'
	the_player.directions = ['Curling Street','March Street', '22nd Street', 'Foreman Ave']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s of Curling Street again." % the_player.location
		print "You've been here before."
	
		if the_player.location in the_player.visited and 'charlie sleepover' in the_player.visited:
			print "The sound is definitely coming from Curling Street."
		else:
			pass

	else:
		the_player.visited.append(the_player.location)

		print "You pass few building in Curling Street"
		print "carefully. Thankfully no zombies are present here."
		print "Behind you is Curling Street, on your right"
		print "you can go to March Street, on your left"
		print "there's 22nd Street."
		print "If you continue to go forward you will enter Foreman Ave."

	while True:
		action = prompt.standard(the_player)
		
		if action == "curling street" and 'got the motor' in the_player.visited:
			print "The zombies are still herding in Curling Street and"
			print "you've already got what you need."

		elif action == "curling street" and 'charlie sleepover' in the_player.visited and 'Wanda' in the_player.visited:
			print "From afar you see a herd of zombies scattered in the street."
			print "Wanda: 'Let's go I have a plan.'"

			custom_error.errortype(4)
			return 'Curling Street'

		elif action == "curling street" and 'charlie sleepover' in the_player.visited:
			print "You go few meters but after a while you notice zombie sounds."
			print "A swarm of deads is scattered around the whole Curling Street."
			print "It doesn't look like a good idea to go there"
			print "but if you really want you might give it a shot:\n"

			while True:
				go_to_swarm = raw_input("> Continue? Y/N").lower()
				if go_to_swarm == "y":
					return 'Curling Street'
				elif go_to_swarm == "n":
					print "You decide to return to junction."
					break
				else:
					print "Type only 'Y' or 'N'."

		elif action == "curling street":
			return 'Curling Street'
		elif action == "march street":
			return 'March Street'
		elif action == "22nd street":
			return '22nd Street'
		elif action == 'foreman ave' or action == "foreman avenue":
			return 'Foreman Ave'
		elif action == 'knife':
			the_player.inventory['knife'] = 50
			print "You pick up knife"
		else:
			custom_error.errortype(3)


import random
import handler
import sys
import hint
import custom_error
import score
import death

def standard(the_player):

	push_ups = 1

	while True:
		
		user_input = str(raw_input("> ")).lower()		

		if user_input == "save":
			handler.save(the_player)
		elif user_input == "inventory" or user_input == "inv":
			print "Inventory:"
			for key, item in the_player.inventory.items():
				condition = item

				if condition > 0 and condition <= 5:
					print_condition = "weak"
				elif condition > 5 and condition <= 15:
					print_condition = "OK"
				else:
					print_condition = "fine"
				
				if key == 'knife' or key == 'baseball bat':					
					print "- %s (%s)" % (key, print_condition)
				elif key == 'gun':
					print "- %s (%d bullets left)" % (key, item)
				elif item > 0:
					print "- %s (%d)" % (key, item)
				elif item <= 0:
					pass

		elif user_input == "char":
			print "\n---", the_player.name, "---"
			print "Age:", the_player.age
			print "Is male?:", the_player.male
			print "Hitpoints: %.1f" % the_player.hitpoints, "/ %.1f" % the_player.max_hitpoints 
			print "Current location:", the_player.location
			print "Score:", the_player.score, "points","\n"
		elif user_input == "help":
			game_help()
		elif user_input == "look":
			print "You can go to:", ", ".join(the_player.directions)
		elif user_input == "hint":
			print "Hint:", hint.location(the_player.location)
		# EASTER EGG
		elif user_input == "push up" and the_player.age > 90:
			death.type(4, the_player)
		elif user_input == "push up" and push_ups > 18:
			death.type(5, the_player)
		elif user_input == "push up":
			push_up = score.calculate(the_player, 'push up')
			print "You've done %d sets of push ups." % push_ups
			push_ups = push_ups + 1
		elif user_input == "heal":
			if 'bandage' not in the_player.inventory.keys() or the_player.inventory['bandage'] == 0:
				print "You do not have bandage."

			elif the_player.hitpoints >= the_player.max_hitpoints:
				print "You don't need to heal yourself."

			elif the_player.inventory['bandage'] > 0:
				healed_hp = random.uniform(11.0,15.0)
				the_player.hitpoints = the_player.hitpoints + healed_hp
				the_player.inventory['bandage'] = the_player.inventory['bandage'] - 1

				if the_player.hitpoints > the_player.max_hitpoints:
					over_hp = the_player.hitpoints - the_player.max_hitpoints
					the_player.hitpoints = the_player.max_hitpoints
					healed_hp = healed_hp - over_hp
				else:
					pass

				print "\nYou heal %.1f hitpoints. (Now: %.1f/%.1f HP). %d bandages left." % (healed_hp, the_player.hitpoints, the_player.max_hitpoints, the_player.inventory['bandage'])
			else:
				pass
		elif user_input == "map":
			if 'map' in the_player.inventory.keys():
				print """
				WELTON SUBURBS MAP

 Left____Another St.____Longer St.____Row of H.
   |                                     |
Suburbs...Very long st.____Small h.___Junction____Mansion
   |                                     |
 Right____Regular St.____Shorter St.____St. w/ tree
"""				

			else:
				print "You don't have a map."
		elif user_input == "visited":
			print the_player.visited
		elif user_input == "killed":
			print the_player.killed
		elif user_input == "quit":

			print "Are you sure? Y/N"

			while True:
				to_quit = str(raw_input("> ")).lower()

				if to_quit == "y":
					break
				elif to_quit == "n":
					return ''
				else:
					custom_error.errortype(5)

			print "Do you want to save? Y/N"
				
			while True:
				save_input = str(raw_input("> ")).lower()

				if save_input == "y":
					handler.save(the_player)
					break
				elif save_input == "n":
					break
				else:
					custom_error.errortype(5)
			exit(1)
		else:
			return user_input


def menu():

	while True:
		try:
			user_input = int(raw_input("\nType a number > "))
			return user_input
		except ValueError:
			custom_error.errortype(1)
			

def load_menu():

		while True:
			try:
				user_input = int(raw_input("\nType a number or type 0 to QUIT > "))

				if user_input == 0:
					exit(1)
				else:
					return user_input
			except ValueError:
				custom_error.errortype(1)


def load_game():

	while True:
		try:
			user_input = str(raw_input("\nLoad this character? Y/N > ")).lower()

			if user_input == "y" or user_input == "n":
				return user_input
			else:
				custom_error.errortype(5)
		except ValueError:
			custom_error.errortype(3)

def select_weapon():

	while True:
		try:
			user_input = int(raw_input("\nSelect weapon (number) > "))
			return user_input
		except ValueError:
			custom_error.errortype(1)
		except IndexError:
			return None


def conversation():

	while True:
		try:
			user_input = int(raw_input("\nSelect answer (number) > "))
			return user_input
		except ValueError:
			custom_error.errortype(1)




def game_help():

	print "\n"
	print "-" * 80
	print "Type HELP anytime to display this message."
	print "-" * 80
	print "Type these commands anytime to perform actions:"
	print " * LOOK: See where you can go."
	print " * HINT: If you're stuck, you can get little help."
	print " * SAVE: Save your progress."
	print " * INV: Will display contents of your inventory."
	print " * CHAR: Shows character stats."
	print " * HEAL: Will heal your char if you have bandage(s)."
	print " * QUIT: Quit game."
	print "\n *** Don't use verbs with things, just nouns. ***\n"





import prompt
import custom_error
import score
import fight

def enter(the_player):

	the_player.location = 'Old Building (first floor)'
	the_player.directions = ['Old Building', 'Old Building (second floor)']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		dave = False

		print "You're on %s again. Dave's corpse is still here." % the_player.location
		print "You can go down in Old Building Lobby or up"
		print "in to second floor."

		if 'Wanda' in the_player.visited and 'Dave is dead' in the_player.visited:
			print "\nYou see Wanda turning away from Dave's body."
			print "'Let's go' she says."

		elif 'Wanda' in the_player.visited:
			print "\nWanda: 'My god... that's David... or what's left of him!'"
			print "She starts sobbing uncontrollably. You decide"
			print "that it's best if you just go."

		else:
			pass
	
	else:
		the_player.visited.append(the_player.location)

		dave = True

		print "You see that the light comes from the windows"
		print "that were not boarded up."
		print "You see a grafitti painted on eastern wall"
		print "saying 'DON'T GO UP!'."
		print "You go to near the window to look outside."
		print "You scan the horizon towards Curling Street"
		print "and see a pack of zombies coming towards you."
		print "You quickly step away from the window and"
		print "immediately hear growling breath behind you."
		print "You quickly turn around to see decomposed"
		print "guy in uniform." 
		print "He reminds you if pizza delivery boy"
		print "that you used to meet."

		custom_error.errortype(4)

		if 'Wanda' in the_player.visited:
			print "'DAVE!' Wanda shouts. 'Please let's leave him"
			print "alone!'"
		else:
			pass

		custom_error.errortype(4)

		print "It's weird. He has a leash on his neck and"
		print "he angrily swings his arm towards you,"
		print "clenching his teeth."
		print "You try to slide past him but pizza boy"
		print "snaps into amok."
		print "In one moment the rope on his leash snaps."
		print "Ooops..."

		custom_error.errortype(4)

		encounter = fight.Encounter(the_player, 'Dave')
		encounter.start(the_player)

		dave = False

		the_player.visited.append('Dave is dead')

		if 'Wanda' in the_player.visited:
			print "'Oh my what did we just do? ..."
			print "I guess it was necessary... but.."
			print "poor Dave. He didn't deserve this.'"
			custom_error.errortype(4)
		else:
			pass

		print "Breathing heavily you observe remains of this"
		print "familiar guy and notice a name tag on his"
		print "shirt. It says 'DAVE'."

	while True:
		action = prompt.standard(the_player)

		if action == "dave" and 'dave chocolate' in the_player.visited:
			print "There's not anything on Dave."

		elif action == "dave" and not 'dave chocolate' in the_player.visited:
			the_player.visited.append('dave chocolate')
			print "You quickly search Dave's body"
			print "and to your surprise you find"
			print "old chocolate but it still looks OK."

			if 'chocolate bar' in the_player.inventory.keys():
				print "Cool another chocolate bar."
				the_player.inventory['chocolate bar'] = the_player.inventory['chocolate bar'] + 1
				print "You have %d bars now." % the_player.inventory['chocolate bar']
				score.calculate(the_player, 'chocolate bar')
			elif 'chocolate bar' not in the_player.inventory.keys():
				the_player.inventory['chocolate bar'] = 1
				score.calculate(the_player, 'chocolate bar')
		elif action == "second floor" or action == "old building (second floor)":
			return 'Old Building (second floor)'
		elif action == "lobby" or action == "old building":
			return 'Old Building'
		else:
			custom_error.errortype(3)





import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Suburb Junction'

	if 'Wanda' in the_player.visited:
		the_player.directions = ['Street with a tree',
								'Row of houses',
								'Street with small houses',
								'Wanda\'s house street']

	else:
		the_player.directions = ['Street with a tree',
								'Row of houses',
								'Street with small houses',
								'Street with large mansion']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
		print "Everything looks normal here."
	else:
		the_player.visited.append(the_player.location)

		print "You enter a junction with the same houses"
		print "around. You can go to:"
		print "%s." % ','.join(the_player.directions)
		print "You're not sure where to go but you hear"
		print "louder dog barking from the direction"
		print "of Street with a large mansion."

	while True:
		action = prompt.standard(the_player)

		if action == "street with a tree" or 'tree' in action:
			return 'Suburb 6'
		elif action == "row of houses" or 'row' in action:
			return 'Suburb 5'
		elif action == "street with small houses" or 'small houses' in action:
			return 'Small houses'
		elif action == "street with large mansion" or 'mansion' in action or 'wanda' in action:
			return 'Cherry trees'
		else:
			custom_error.errortype(3)


import custom_error
import prompt
import score
import fight

def workbench(the_player):

	print "You're at huge wooden workbench with some tools around."
	print "You inspect your stuff if you can make something useful,"

	cart_items = ['wheels','wooden board','broom']
	available_items = []

	for item in cart_items:
		if item in the_player.inventory.keys():
			available_items.append(item)
		else:
			pass

	
	if available_items == []:
		print "but you don't know what to do."
	elif 'cart' in the_player.inventory.keys():
		print "You've already built the cart so there's no need to mess around."
	else:
		print "and seems like %s is useful." % ' and '.join(available_items[0:len(available_items)])

		if 'wheels' in available_items and 'wooden board' in available_items and 'broom' in available_items:
			print "\nGreat! You create a box from wooden boards and then you nail"
			print "the bicycle wheels onto it. You use the broom stick as a lever"
			print "so you can push it. You've created a carrying cart!"

			del the_player.inventory['wheels']
			del the_player.inventory['wooden board']
			del the_player.inventory['broom']

			the_player.inventory['cart'] = 1
			score.calculate(the_player,'cart')
		elif 'wheels' in available_items and 'wooden board' in available_items:
			print "You get an idea to create a box from wooden boards and attach"
			print "the bicycle wheels but you still need some kind of lever"
			print "to push it."
		elif 'wheels' in available_items and 'broom' in available_items:
			print "You've got wheels and broom but there is still something missing."
		elif 'broom' in available_items and 'wooden board' in available_items:
			print "You can try to build a box from wooden boards and attach"
			print "the broom stick, but still the thing will be unmovable."
		elif 'wheels' in available_items:
			print "You've got two wheels but you need some kind of box"
			print "made from some solid material so you can put stuff in it."
		elif 'wooden board' in available_items:
			print "Your wooden boards can be made into a box. It's nice for starters"
			print "but you need to move it somehow."
		elif 'broom' in available_items:
			print "Your broom can be disassembled and the handle will be useful"
			print "as a lever. On its own it doesn't do much."
			print "There is one more thing missing."
		else:
			pass

def enter(the_player):

	the_player.location = 'Maintenance room'
	the_player.directions = ['Motor Shop', 'Restroom']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "You're back at the %s." % the_player.location

	else:
		the_player.visited.append(the_player.location)

		print "You open the door and something immediately jumps at you!"

		custom_error.errortype(4)

		the_player.visited.remove('Wanda')

		encounter = fight.Encounter(the_player, 'random')
		encounter.start(the_player)

		the_player.visited.append('Wanda')

		print "That was close!"

	print "In front of you, you see lots of junk. There is a closet on the left"
	print "and next to it is some kind of workbench."
	print "There are also paper boxes and wooden crates around the place."
	print "On your right you see doors marked 'restroom'."

	while True:
		
		action = prompt.standard(the_player)

		if action == 'restroom' or 'rest' in action:
			return 'Restroom'
		elif action == "closet":
			if 'wheels' in the_player.inventory.keys():
				print "There isn't anything useful in there anymore."
			else:
				print "You find some spare bike parts. Everything looks functional"
				print "and the wheels might be useful for something so you take them."
				the_player.inventory['wheels'] = 2
		elif action == "workbench":
			workbench(the_player)
		elif action == "paper boxes" or action == "boxes":
			print "You don't find anything useful."
		elif action == "wooden crates" or action == "crates" or action == "crate":
			if 'wooden board' in the_player.inventory.keys():
				print "The crates are already disassembled and there is"
				print "nothing of use to you."
			else:
				print "You inspect wooden crates and nothing if interest"
				print "is inside them, just some random junk."
				print "But the crates themselves are made of wooden boards"
				print "that you think you could use."
				print "You take few of the crates apart and get several boards."
				the_player.inventory['wooden board'] = 5
		elif action == "motor shop" or action == "shop":
			return 'Motor Shop'
		else:
			custom_error.errortype(3)



# -*- coding: utf-8 -*-

import prompt
import custom_error
import score
import death

def enter(the_player):

	the_player.location = 'Old Building'
	the_player.directions = ['March Street','Old Building (first floor)']

	print "\nLocation:", the_player.location
	print "-" * 30

	num_of_tries = 4

	if the_player.location in the_player.visited and 'flashlight' in the_player.inventory.keys():
		print "You turn on the flashlight. Suddenly you can see all"
		print "the dead bodies in the room."

		if 'first time flash light' in the_player.visited:
			print "You see the trunk."


		else:
			the_player.visited.append('first time flash light')
			score.calculate(the_player,'turn on lights')

			print "Apart from the horrendous scene you notice a large trunk"
			print "in the back of the room."
			print "You come closer to open it but discover that"
			print "it has a mechanical lock on it with three"
			print "cylinders with number on them."
			print "The trunk has letters 'AK' crudely painted on it."

			if 'Wanda' in the_player.visited:
				print "\nWanda: 'That trunk is where our stuff should be.'"


	elif the_player.location in the_player.visited:

		print "You are at the lobby of %s again. It's dark here." % the_player.location

	else:
		the_player.visited.append(the_player.location)

		print "It's very dark inside and the smell is horrible."
		print "You can't see anything but you see a little"
		print "light coming from the other side of the lobby."
		print "You see some stairs leading up to first floor."

		if 'Wanda' in the_player.visited:
			print "\nWanda: 'This is it, this is the building. The stuff"
			print "must be somewhere here.'"

	while True:
		action = prompt.standard(the_player)

		if action == "march street" or 'out' in action:
			return 'March Street'
		elif action == "stairs" or action == "first floor":
			return 'Old Building (first floor)'
		elif action == "trunk" and not 'map' in the_player.inventory.keys():

			if 'Wanda' in the_player.visited:
				print "\n'The code is 498 but be careful"
				print "because you only have few tries."
				print "There's a special poison needle"
				print "to avoid hassling with the lock'"
			else:
				pass

			while True:
				if num_of_tries != 0:
					try:
						passcode = int(raw_input("Enter three digits, '000' to go away > "))
						num_of_tries = num_of_tries - 1
					except ValueError:
						print "Put three numbers only"
					if passcode == 000:
						break
					elif passcode == 498:
						the_player.inventory['boat key'] = 1
						score.calculate(the_player, 'key')

						print "You find some junk inside but most importantly,"
						print "the key for the boat is there. It is squared-shaped"
						print "and kind of unique."

						if 'Wanda' in the_player.visited:
							print "Wanda: 'We got the key! Let's go.'"
						else:
							pass
						break
					else:
						print "It's still locked."
				else:
					death.type(9, the_player)


		else:
			custom_error.errortype(3)
			pass


import string
import random
import prompt
import custom_error
import score


def shelf(the_player):


	shelves = [i for i in string.ascii_lowercase]
	shelves_view = ', '.join(shelves).upper()

	while True:
		
		print "\nShelves are labeled as:\n%s." % shelves_view

		try:
			select = str(raw_input("Type letter to inspect shelf, 'exit' to stop > ")).lower()

			if select == "exit":
				return 'Warehouse'
			elif select in shelves:
				single_shelf(select, the_player)
			else:
				custom_error.errortype(3)
				custom_error.errortype(4)
		except ValueError:
			print "Type letters only"

def single_shelf(shelf_id, the_player):

	compartments = []

	for item in range(1,6):
		compartment = shelf_id
		compartments.append((compartment, item))

	print "You come to shelf %s and see compartmens marked as:" % shelf_id.upper()
	
	for compartment in compartments:
		print compartment[0].upper() + str(compartment[1])

	while True:
		select = str(raw_input("Type letter and number to look into container, 0 to go back > ")).lower()

		if select == "0":
			break
		elif len(select) == 1:
			print "Please specify container."
		elif select == "t1" and shelf_id == "t" and 'motor' in the_player.inventory.keys():
			print "There is nothing else in that container."
		elif select == "t1" and shelf_id == "t":
			print "\nYou found the motor!"
			score.calculate(the_player, 'find motor')
			the_player.inventory['motor'] = 1
			
			if 'cart' in the_player.inventory.keys():
				print "You put the motor in the cart. You're ready to go!"
			else:
				print "You can carry the motor for few meters but it is very heavy."
				print "You're gonna need something for carrying it."
			custom_error.errortype(4)
			return 'Warehouse'
		elif select == "a2" and shelf_id == "a" and 'gun' in the_player.inventory.keys():
	
			if 'warehouse bullets' not in the_player.visited:
				bullets = random.randint(3,7)
				print "\nYou found %d bullets for gun." % bullets
				score.calculate(the_player,'bullets')
				the_player.inventory['gun'] = the_player.inventory['gun'] + bullets
				the_player.visited.append('warehouse bullets')
			else:
				print "\nThere is nothing else inside."
		elif select == "h4" and shelf_id == "h":
			print "You find a note:"
			print "'PUSH UP' to be the best."
			score.calculate(the_player,'easter egg')
			return 'Warehouse'
		elif select == "q2" and shelf_id == "q":
			print "You find a note:"
			print "'I wish I could write better code...' - author."
			score.calculate(the_player,'easter egg')
		elif shelf_id not in select:
			print "That container is not here."
		else:
			print random.choice(["It's empty.","There's some random junk inside","A weird steel thing!", "Nothing of interest."])

def enter(the_player):

	the_player.location = 'Warehouse'
	the_player.directions = ['Motor Shop']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "You're back at the warehouse of B&D Motor shop."

	else:
		the_player.visited.append(the_player.location)

		print "The door says 'Warehouse' and you"
		print "carefully approach it and open it."
		print "Inside is a large area that was intended"
		print "as a storage facility."
		print "You see multiple columns of shelves"
		print "with letters and numbers on them."

	while True:
		
		print "\nYou stand in front of the shelves, behind you"
		print "is a door leading to %s." % the_player.directions[0]
		
		action = prompt.standard(the_player)

		if action == "shelf" or action == "shelves":
			shelf(the_player)
		elif action == "motor" or action == "motor shop":
			return 'Motor Shop'
		else:
			custom_error.errortype(3)
			



import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Suburbs'
	the_player.directions = ['22nd Street','Left','Right']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You've reached %s, you're standing in" % the_player.location
		print "one of the front streets."

	else:
		the_player.visited.append(the_player.location)

		print "Few minutes later you arrive to Welton"
		print "suburbs. The street you're on forks"
		print "into two roads (left and right)."
		print "In the distance you see many other roads"
		print "but everything looks so similiar."
		print "All the houses are same size and all"
		print "the lawns are green."
		print "Where do you go?"


	while True:
		action = prompt.standard(the_player)

		if action == "22nd street":
			return '22nd Street'
		elif action == "left":
			return 'Suburb 1'
		elif action == "right":
			return 'Suburb 2'
		else:
			custom_error.errortype(3)




import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Shorter street'
	the_player.directions = ['Regular street','Street with a tree','House with pirate flag']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
		print "There's the house with the pirate flag."
	else:
		the_player.visited.append(the_player.location)

		print "The street is very similar to the one"
		print "You came from, except that you notice"
		print "there's a pirate flag on one of the"
		print "houses."
		print "You hear a distant dog bark."
		print "Up ahead you see that there's a tree"
		print "in next street."


	while True:
		action = prompt.standard(the_player)

		if action == "regular street":
			return 'Suburb 2'
		elif action == "street with a tree" or 'tree' in action:
			return 'Suburb 6'
		elif 'pirate' in action or 'flag' in action:
			return 'House with pirate flag'
		else:
			custom_error.errortype(3)



import random
import copy
import prompt
import score
import custom_error
import death
import enemies

class Encounter(object):


	def __init__(self, the_player, enemy):
		self.the_player = the_player
		self.enemy = enemy

	
	def player_attack(self, the_player, the_enemy):

		weapon_stats = {
		'fists': random.randint(1,6),
		'gun': random.randint(30,35),
		'knife': random.randint(10,15),
		'baseball bat': random.randint(8,13) + random.randint(2,6),
		}

		weapons = self.player_weapon(the_player)
		bonus = self.attack_bonus(the_player)

		num_of_weapons = len(weapons)
		w_num = 1

		weapon_table = {}

		print "\nAvailable weapons:"
		while w_num <= num_of_weapons:
	
			for weapon in weapons:
				print str(w_num) + '.' ,weapon
				w_num = w_num + 1
				weapon_table[weapon] = w_num - 1

		selected_weapon = prompt.select_weapon()

		for key, item in weapon_table.items():
			if selected_weapon == item:
				attack_points = weapon_stats.get(key) * bonus
				use_weapon = key
			else:
				pass

		if 'knife' or 'baseball bat' in the_player.inventory.keys():
			for weapon, condition in the_player.inventory.items():

				if condition > 0 and condition <= 5:
					print_condition = "weak"
				elif condition > 5 and condition <= 15:
					print_condition = "OK"
				else:
					print_condition = "fine"
		else:
			pass

		chance_of_missing = random.randint(0,5)	

		if chance_of_missing == 0:
			randomize_attack = 0
		else:
			if use_weapon == 'gun':
				the_player.inventory['gun'] = the_player.inventory['gun'] - 1
				if the_player.inventory['gun'] <= 0:
					attack_points = 0
					print "You don't have enough bullets."
				else:
					pass
			elif use_weapon == 'knife':
				the_player.inventory['knife'] = the_player.inventory['knife'] - 1
				if the_player.inventory['knife'] <= 0:
					attack_points = 0
					print "Your knife is broken." 
			elif use_weapon == 'baseball bat':
				the_player.inventory['baseball bat'] = the_player.inventory['baseball bat'] - 1
				if the_player.inventory['baseball bat'] <= 0:
					attack_points = 0
					print "Your baseball bat is broken."
			else:
				pass

			randomize_attack = attack_points * random.uniform(0.0,1.0)
			the_enemy.enemy_hp = the_enemy.enemy_hp - randomize_attack

		if 'Wanda' in the_player.visited:
			wanda_attack = random.randint(10,12) * random.uniform(0.0,1.0)
			the_enemy.enemy_hp = the_enemy.enemy_hp - wanda_attack
		else:
			pass

		if randomize_attack <= 0:
			print "\nYou miss!"
		else:
			print "\nYou hit %s with %s for %.2f hitpoint damage." % (the_enemy.enemy_name, use_weapon, randomize_attack)
			if use_weapon == 'gun':
				print "%d bullets left.\n" % the_player.inventory['gun']
			elif use_weapon == 'knife' or use_weapon == 'baseball bat':
				print "%s looks %s.\n" % (use_weapon.capitalize(), print_condition)
			else:
				pass

		if 'Wanda' in the_player.visited:

			if wanda_attack <= 0:
				print "\nWanda misses!"
			else:
				print "\nWanda hits %s for %.2f hitpoints." % (the_enemy.enemy_name, wanda_attack)

		
		custom_error.errortype(4)

		if the_enemy.enemy_hp <= 0:
			enemy_alive = False
		else:
			enemy_alive = True

		return enemy_alive


	
	def enemy_attack(self, the_player, the_enemy):

		chance_of_missing = random.randint(0,5)
		chance_of_infection = random.randint(1,50)

		if chance_of_missing == 0:
			randomize_enemy_attack = 0
		else:
			randomize_enemy_attack = the_enemy.enemy_attack * random.uniform(0.0,1.0)
			the_player.hitpoints = the_player.hitpoints - randomize_enemy_attack
			if chance_of_infection == 50:
				death.type(7,the_player)
			else:
				pass

		if randomize_enemy_attack <= 0:
			print "\n%s misses!" % the_enemy.enemy_name
		else:
			print "\n%s hits you for %.2f. You have %.2f hitpoints left." % (the_enemy.enemy_name, randomize_enemy_attack, the_player.hitpoints)

		if the_player.hitpoints <= 0:
			death.type(6, the_player)
		else:
			pass


	
	def player_weapon(self, the_player):
		
		available_weapons = ['fists']
		weapons = ['gun', 'knife', 'baseball bat']

	
		for weapon in weapons:
			if weapon in the_player.inventory.keys():
				available_weapons.append(weapon)
			else:
				pass

		return available_weapons

	def attack_bonus(self, the_player):

		male = the_player.male
		age = the_player.age
		
		if male == True:
			if age < 4:
				bonus = 0.2
			elif age < 8:
				bonus = 0.6
			elif age < 12:
				bonus = 1.1
			elif age < 17:
				bonus = 1.6
			elif age < 26:
				bonus = 2.0
			elif age < 33:
				bonus = 2.3
			elif age < 48:
				bonus = 2.0
			elif age < 61:
				bonus = 1.1
			elif age < 72:
				bonus = 0.8
			else:
				bonus = 0.2
		else:
			if age < 4:
				bonus = 0.2
			elif age < 8:
				bonus = 0.6
			elif age < 12:
				bonus = 1.0
			elif age < 17:
				bonus = 1.4
			elif age < 26:
				bonus = 1.9
			elif age < 33:
				bonus = 1.9
			elif age < 48:
				bonus = 1.8
			elif age < 61:
				bonus = 1.0
			elif age < 72:
				bonus = 0.5
			else:
				bonus = 0.1

		return bonus

	
	def start(self, the_player):


		create_enemy = enemies.SpawnEnemy(the_player, self.enemy)

		if self.enemy == 'random':
			created_enemy = create_enemy.generate_random(the_player)
		else:
			created_enemy = create_enemy.generate(the_player, self.enemy)

		the_enemy = enemies.Enemy(*created_enemy)

		enemy_alive = True

			
		initialize_fight = random.randint(0,1)

		print "\n"
		print "-------------"
		print "--- FIGHT ---"
		print "-------------"
		print "Your enemy is %s.\n" % (the_enemy.enemy_name)

		if initialize_fight == 0:
			print "You are quicker than %s, you get to attack first!" % the_enemy.enemy_name
			fight_order = 'player first'
		else:
			print "%s strikes first!" % the_enemy.enemy_name
			fight_order = 'enemy first'


		while enemy_alive:

			if fight_order == 'player first':
				enemy_alive = self.player_attack(the_player, the_enemy)
				if enemy_alive == True:
					self.enemy_attack(the_player, the_enemy)
				else:
					break

			elif fight_order == 'enemy first':
				if enemy_alive == True:
					self.enemy_attack(the_player, the_enemy)
					enemy_alive = self.player_attack(the_player, the_enemy)
				else:
					break
			else:
				pass

		print "Congratulations you kill %s." % the_enemy.enemy_name
		score.calculate(the_player, the_enemy.enemy_name)

		if the_enemy.enemy_name not in the_player.killed.keys():
			the_player.killed[the_enemy.enemy_name] = 1
		else:
			the_player.killed[the_enemy.enemy_name] = the_player.killed[the_enemy.enemy_name] + 1







# -*- coding: utf-8 -*-

import glob
import os.path
import time
import ast
import player
import game
import prompt
import custom_error


def save(the_player):
	save_file_name = str(the_player.name) + '.sav'
	save_file = open(save_file_name, 'w')
	save_file.truncate()
	save_file.write(str(the_player.name) + "\n")
	save_file.write(str(the_player.age) + "\n")
	save_file.write(str(the_player.male) + "\n")
	save_file.write(str(the_player.inventory) + "\n")
	save_file.write(str(the_player.max_hitpoints) + "\n")
	save_file.write(str(the_player.hitpoints) + "\n")
	save_file.write(str(the_player.location) + "\n")
	save_file.write(str(the_player.visited) + "\n")
	save_file.write(str(the_player.score) + "\n")
	save_file.write(str(the_player.directions) + "\n")
	save_file.write(str(the_player.killed) + "\n")
	save_file.close()
	print "Saved as %s file" % save_file_name

def load():
	print chr(27) + "[2J"
	print "-" * 80
	print "Load game"
	print "-" * 80
	print "These are your previously saved characters:\n"
	
	saved_games = glob.glob('*.sav')

	num_of_saved_games = len(saved_games)+1
	num = 1

	while num < num_of_saved_games:

		for save_game in saved_games:
			print str(num) + '.', save_game.strip(' .sav')
			num = num + 1
	
	while True:
		try:
			action = prompt.load_menu()
			load_file_name = saved_games[action - 1]

			load_file = open(str(load_file_name),'r')
			print "\n--- Your selected character ---"
			print "Name: ", load_file.readline().strip("\n")
			print "Age: ", load_file.readline().strip("\n"), "years"
			print "Is male?: ", load_file.readline().strip("\n")
			
			inv_read = ast.literal_eval(load_file.readline())

			print "Inventory:"
			for key, item in inv_read.items():
				if key == 'gun':
					print "- %s (%d bullets left)" % (key, item)
				elif key == 'knife' or key == 'baseball bat':
					if item > 0 and item <= 5:
						print_condition = "weak"
					elif item > 5 and item <= 15:
						print_condition = "OK"
					else:
						print_condition = "fine"
					print "- %s (%s)" % (key, print_condition)					
				elif item > 0:
					print "- %s (%d)" % (key, item)
				elif item <= 0:
					pass

			print_max_hp = float(load_file.readline().strip("\n"))
			print "Hitpoints: %.1f" % float(load_file.readline().strip("\n")),"/ %.1f" % print_max_hp, "HP"
			print "Location: ", load_file.readline().strip("\n")
			load_file.readline().strip("\n")
			print "Score: ", load_file.readline().strip("\n"), "points"
			load_file.readline().strip("\n")
			print "Save file:", load_file_name
			print "Last played on:", time.ctime(os.path.getmtime(load_file_name))

			choose_to_load = prompt.load_game()

			load_file.seek(0)

			load_player_name = load_file.readline().strip("\n")
			load_player_age = load_file.readline().strip("\n")
			load_player_male = load_file.readline().strip("\n")
			load_player_inventory = load_file.readline().strip("\n")
			load_player_max_hitpoints = load_file.readline().strip("\n")
			load_player_hitpoints = load_file.readline().strip("\n")
			load_player_location = load_file.readline().strip("\n")
			load_player_visited = load_file.readline().strip("\n")
			load_player_score = load_file.readline().strip("\n")
			load_player_directions = load_file.readline().strip("\n")
			load_player_killed = load_file.readline().strip()

			load_file.close()

			load_player_age = convert_save_file(load_player_age)
			load_player_max_hitpoints = convert_save_file(load_player_max_hitpoints)
			load_player_hitpoints = convert_save_file(load_player_hitpoints)
			load_player_male = convert_save_file(load_player_male)
			load_player_inventory = convert_save_file(load_player_inventory)
			load_player_visited = convert_save_file(load_player_visited)
			load_player_score = convert_save_file(load_player_score)
			load_player_directions = convert_save_file(load_player_directions)
			load_player_killed = convert_save_file(load_player_killed)

			if choose_to_load == "y":

				load_player = player.Player(load_player_name, 
									load_player_age, load_player_male, 
									load_player_inventory, load_player_max_hitpoints, 
									load_player_hitpoints, load_player_location, 
									load_player_visited, load_player_score, 
									load_player_directions, load_player_killed)

				load_game = game.Engine(load_player, load_player_location)
				load_game.move()

			elif choose_to_load == "n":
				load_file.close()
				load()

		except IndexError:
			print "This save game does not exit."


def convert_save_file(file_content):
	converted_content = ast.literal_eval(file_content)
	return converted_content



import prompt
import death
import custom_error

def enter(the_player):

	the_player.location = 'Marina'
	if 'Wanda' in the_player.visited:
		the_player.directions = ['Harrington River','Wanda\'s boat']
	else:
		the_player.directions = ['Harrington River','Yellow boat']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "You're back at %s." % the_player.location
		print "You see two smaller boats and %s." % the_player.directions[1]

	else:
		the_player.visited.append(the_player.location)

		print "You come to little Marina and notice two small"
		print "boats with paddle and larger yellow boat."

		if 'Wanda' in the_player.visited:
			print "Wanda: 'That yellow boat is the one!'"
		else:
			pass


	while True:

		action = prompt.standard(the_player)

		if action == "river" or action == "harrington river":
			return 'Harrington River'
		elif 'yellow' in action or 'boat' in action or 'wanda\'s boat' in action:
			return 'Wanda\'s boat'
		elif action == "small boat" or action == "small boats":
			print "One of the small boats is half-sunken and the other"
			print "looks crappy too. There are also no paddles."
		else:
			custom_error.errortype(3)


import random
import prompt
import score
import custom_error

def junk(the_player):
	
	dives = 0
	dive_messages = ["You fail to find anything.",
					"Still nothing",
					"You're looking but it's just junk.",
					"Useless junk",
					"Some crap you don't need.",
					"Some dusty thing",
					"Nothing interesting"]

	print "\nYou dive into the junk."

	while dives <= random.randint(8,15):

		chance = random.randint(1,6)
		map_chance = random.randint(1,8)
		dive = raw_input("ENTER to dive, 'S' to stop > ").lower()
		custom_error.errortype(4)

		if dive == "s":
			break
		else:
			dives = dives + 1

			if chance == 4 and 'baseball bat' not in the_player.inventory.keys():
				print '\nYou find a baseball bat!'
				the_player.inventory['baseball bat'] = 10
				score.calculate(the_player, 'baseball bat')
				break
			elif map_chance == 7 and 'map' not in the_player.inventory.keys():
				print "You find a map of the Suburbs!"
				the_player.inventory['map'] = 1
				score.calculate(the_player,'map')
				print "Type 'MAP' to display map."
				break
			else:
				print '\n', random.choice(dive_messages)

	print "\nYou're bored so you need to rest for a while."

def enter(the_player):

	the_player.location = 'Basement'

	the_player.directions = ['Hallway of the house']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		if 'flashlight' in the_player.inventory.keys():
			print "Back in the %s." % the_player.location
			print "Heaps of junk everywhere."
		elif 'flashlight' not in the_player.inventory.keys():
			print "You're back at %s but it's still dark here."
			print "You can't see anything."

	else:
		the_player.visited.append(the_player.location)

		if 'flashlight' in the_player.inventory.keys():
			print "Thankfully you have flashlight with you"
			print "so you turn it on."
			print "You're in some kind of a basement that"
			print "has brick walls. It's very humid here."
			print "There's a lot of junk laying around."


		elif 'flashlight' not in the_player.inventory.keys():
			print "You step into the darkness and listen for"
			print "a while. It's silent and very humid in here"
			print "but also no light available."

	while True:
		
		action = prompt. standard(the_player)

		if 'house' in action or 'out' in action or 'hallway' in action:
			return 'House with pirate flag'
		elif 'junk' in action:
			junk(the_player)
		else:
			custom_error.errortype(3)



def calculate(the_player, experience):

	experiences = {
	'chocolate bar': 8,
	'out of the house': 5,
	'gun': 10,
	'bullets': 5,
	'knife': 10,
	'push up': 10,
	'child zombie': 14,
	'Dave': 22,
	'zombie male': 22,
	'zombie overlord': 100,
	'zombie with missing arm': 20,
	'flashlight': 25,
	'baseball bat': 10,	
	'glass': 20,
	'map': 20,
	'brass key': 15,
	'charlie hit': 10,
	'turn on lights': 10,
	'key': 50,
	'infected dog': 17,
	'decomposed old man': 5,
	'decomposed old woman': 6,
	'teethless zombie': 1,
	'wanda decoy': 36,
	'find motor': 15,
	'cart': 20,
	'zombie captain': 55,
	'end game': 100,
	'easter egg': 20
	}

	xp_value = experiences.get(experience)

	age = the_player.age
	sex = the_player.male

	if sex is True:
		sex_multiplier = 4
	else:
		sex_multiplier = 5

	if age < 10:
		age_multiplier = 25
	elif age >= 10 and age < 18:
		age_multiplier = 23
	elif age >= 18 and age < 33:
		age_multiplier = 22
	elif age >= 33 and age < 59:
		age_multiplier = 19
	else:
		age_multiplier = 17

	
	calculated_xp = xp_value * sex_multiplier * age_multiplier

	the_player.score = the_player.score + calculated_xp

	print "\nYou get %d score points! %d total score.\n" % (calculated_xp, the_player.score)


	return calculated_xp


import random
import prompt
import custom_error
import fight

def enter(the_player):

	the_player.location = '22nd Street'
	the_player.directions = ['Junction','Suburbs']

	print "\nLocation:", the_player.location
	print "-" * 30

	chance_of_encounter = random.randint(0,1)

	if chance_of_encounter == 1:
		print "You hear growling... Looks like"
		print "an enemy stumbled upon you.\n"
		encounter = fight.Encounter(the_player,'random')
		encounter.start(the_player)
		random.seed(chance_of_encounter)
	else:
		pass

	if the_player.location in the_player.visited:

		print "Your at %s again." % the_player.location

	else:
		the_player.visited.append(the_player.location)
		
		print "You come to %s, it looks empty here." % the_player.location
		print "If you continue going forward, you'll"
		print "reach Suburbs of Welton."


	while True:
		action = prompt.standard(the_player)

		if action == "suburbs":
			return 'Suburbs'
		elif action == "junction":
			return 'Junction'
		else:
			custom_error.errortype(3)








import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Regular street'
	the_player.directions = ['Suburbs','Shorter street']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
	else:
		the_player.visited.append(the_player.location)

		print "Just another street with rows of houses."
		print "There is basically same street up ahead"
		print "but a little shorter."


	while True:
		action = prompt.standard(the_player)

		if action == "suburbs":
			return 'Suburbs'
		elif action == "shorter street":
			return 'Suburb 4'



import prompt
import custom_error
import fight

def enter(the_player):

	the_player.location = 'March Street'
	the_player.directions = ['Junction','Old building','Harrington River']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You come back to %s. You've been here before." % the_player.location
		print "Old building is on your left side, ahead is Junction"
		print "of Curling Street"

		if 'charlie sleepover' in the_player.visited:
			print "You hear a very distant noise, probably coming"
			print "from Junction of Curling Street."
		else:
			pass

	else:
		the_player.visited.append(the_player.location)

		print "You leave junction of Curling Street behind"
		print "and turn right to %s." % the_player.location
		print "You see something moving towards you and feel"
		print "uneasiness and chill in your spine."

		encounter = fight.Encounter(the_player, 'child zombie')
		encounter.start(the_player)

		print "You successfully killed the enemy. Now you can safely"
		print "look around."
		print "Just by the sidewalk is an old building with grey walls."
		print "It is a three story building and there's a little light"
		print "coming out of the top window."
		print "Most of the windows, especially in ground floor are boarded up."
		print "If you continue walking you will end up near Harrington River."
		print "You can also turn back to Junction of Curling Street."

	while True:
		action = prompt.standard(the_player)

		if action == "junction":
			return 'Junction'
		elif action == "old building":
			return 'Old Building'
		elif action == "harrington river":
			return 'Harrington River'
		else:
			custom_error.errortype(3)

	


import prompt
import custom_error

def enter(the_player):

	the_player.location = 'Longer street'
	the_player.directions = ['Another street','Row of houses']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
		print "You still hear the dog barking."
	else:
		the_player.visited.append(the_player.location)

		print "Just another street."
		print "There is a street with row of houses ahead."
		print "On your right there's a patch of flowers"
		print "that isn't on other lawns."
		print "You hear barking from afar."


	while True:
		action = prompt.standard(the_player)

		if action == "another street":
			return 'Suburb 1'
		elif 'row' in action or 'houses' in action:
			return 'Suburb 5'
		elif action == "patch of flowers" or action == "flower":
			print "You smell the flowers. They smell nice."
			print "You look inside the house where the flowers"
			print "are but there's nothing special about it."
		else:
			custom_error.errortype(3)



import prompt
import custom_error
import fight

def enter(the_player):

	the_player.location = 'House with pirate flag'

	if the_player.location in the_player.visited and 'dog in pirate house' in the_player.visited:
		the_player.directions = ['Shorter street','Room with dead dog','Kitchen','Basement']
	elif the_player.location in the_player.visited and 'dog in pirate house' not in the_player.visited:
		the_player.directions = ['Shorter street','Left door','Right door','Stairs']
	else:
		the_player.directions = ['Shorter street','Left Door','Kitchen','Stairs']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You're back at %s." % the_player.location
		print "There's a %s on your left, %s on your right" % (the_player.directions[1], the_player.directions[2])
		print "and stairs leading to %s." % the_player.directions[3]
	else:
		the_player.visited.append(the_player.location)

		print "It smells really bad in here. From where"
		print "you stand you see two doors, one on the"
		print "right and one on the left."
		print "You hear loud barking coming from behind"
		print "the left door."
		print "There are stairs leading down at the end"
		print "of the hall."
		print "Door behind you leads out to the street."


	while True:
		action = prompt.standard(the_player)

		if action == "shorter street" or 'shorter' in action or 'out' in action:
			return 'Suburb 4'
		elif 'left' in action or 'dog' in action:
			if 'dog in pirate house' not in the_player.visited:
				print "You open the wooden doors and angry dog jumps at you!"

				encounter = fight.Encounter(the_player,'infected dog')
				encounter.start(the_player)
				the_player.visited.append('dog in pirate house')

				print "There is nothing interesting in that room so you go out."
			else:
				print "Nothing here just the dead dog. You return to the hall."
		elif 'stairs' in action or 'basement' in action:
			return 'Basement'
		elif 'right' in action or 'kitchen' in action:
			return 'Kitchen'
		else:
			custom_error.errortype(3)


from setuptools import setup

setup(
	name='ZombieAdventure',
	version='1.0.1',
	author='comatory',
	author_email='osekdomains@gmail.com',
	packages=['bin','zombieadventure'],
	scripts=['bin/zombieadv.py'],
	url='https://github.com/comatory/ZombieAdventure',
	license='LICENSE.txt',
	description='Text-based survival adventure game in post-apocalyptic society.',
	long_description=open('README.txt').read(),
	entry_points={'console_scripts':['zombieadv = bin.zombieadv.py']}
	)



import prompt
import fight
import score
import custom_error

def enter(the_player):

	if 'Wanda' in the_player.visited:
		the_player.location = 'Wanda\'s boat'
	else:
		the_player.location = 'Yellow boat'

	the_player.directions = ['Marina']

	print "\nLocation:", the_player.location
	print "-" * 30

	if 'zombie captain' not in the_player.visited:

		print "Looks like a habitant of Marina has turned."
		print "You see funny looking dead in striped shirt"
		print "and captain's hat... but boy he's ripped"
		print "as hell..."

		custom_error.errortype(3)

		encounter = fight.Encounter(the_player,'zombie captain')
		encounter.start(the_player)

		the_player.visited.append('zombie captain')

	else:
		pass


	if 'Wanda' in the_player.visited:
		if the_player.location in the_player.visited:
			print "You're back at %s." % the_player.location
			print "Wanda: 'OK, let's get this thing going.'"
		else:
			the_player.visited.append(the_player.location)

			print "Wanda: 'So this is the boat that me and"
			print "Dave found.'"

			print "You both inspect the ship and see that the"
			print "motor is indeed missing. Also the boat"
			print "needs special key to operate."
	else:
		pass

	if the_player.location in the_player.visited:
		print "You're back at the %s." % the_player.location


	else:
		the_player.visited.append(the_player.location)
		print "You inspect the boat and notice that the motor is missing."
		print "Also you need special key to operate the boat."


	while True:
		
		action = prompt.standard(the_player)

		if 'motor' in action and 'motor' in the_player.inventory.keys():
			print "You install the motor onto the boat. There seems to"
			print "be enough fuel left in tanks. Now all you need"
			print "is to start the motor."

			the_player.visited.append('motor installed')
		elif 'start' in action or 'key' in action or 'boat key' in action:
			print "You put the boat key in the ignition."

			if 'motor installed' in the_player.visited:
				print "You hear the motor start."
				score.calculate(the_player,'end game')
				custom_error.errortype(4)
				return 'Ending'
			else:
				print "Nothing happens, the motor is still missing."
		elif action == "marina":
			return 'Marina'
		else:
			custom_error.errortype(3)


import custom_error
import prompt
import score

def laptop(the_player):

	computer = True

	while computer:
		
		print "\n--- Welcome to ShopDB ver. 3.0 ---"
		print "\nPlease select number, type '0' to log out:"
		print "1. Browse inventory"
		print "2. Billings"
		print "3. Employees"


		computer_prompt = int(raw_input("> "))

		if computer_prompt == 1:

			computer2 = True
			
			while computer2:

				print "\n1. Axx - Gxx"
				print "2. Hxx - Oxx"
				print "3. Mxx - Zxx"
				print "4. <- back"

				computer_prompt2 = int(raw_input("> "))

				if computer_prompt2 == 1:

					computer3 = True

					while computer3:

						print "\n1. A6-HJT3"
						print "2. C5-TZ"
						print "3. F3-763G"
						print "4. G1-GG"
						print "5. <- back"

						computer_prompt3 = int(raw_input("> "))

						if computer_prompt3 == 5:
							print "..."
							computer3 = False
						else:
							print "Nothing of interest here."

				elif computer_prompt2 == 2:

					computer4 = True

					while computer4:

						print "\n1. H5-I54"
						print "2. K5-22TS"
						print "3. L0-002"
						print "4. <- back"

						computer_prompt4 = int(raw_input("> "))

						if computer_prompt4 == 2:
							print "Yes that's the number Wanda was talking about."
							print "It says it's in the Warehouse on shelf T-1."
							score.calculate(the_player,'find motor')
							print "You log out of computer."
							computer5 = False
							computer4 = False
							computer3 = False
							computer2 = False
							computer = False

						elif computer_prompt4 == 4:
							print "..."
							computer4 = False
						else:
							print "Nothing of interest here."

				elif computer_prompt2 == 3:

					computer5 = True

					while computer5:

						print "\n1. N7-44F"
						print "2. T9-F"
						print "3. WK-991"
						print "4. <- back"

						computer_prompt5 = int(raw_input("> "))

						if computer_prompt5 == 4:
							print "..."
							computer5 = False
						else:
							print "Nothing of interest here."

				elif computer_prompt2 == 4:
					computer2 = False
					print "..."

				else:
					custom_error.errortype(3)

		elif computer_prompt == 2:
			print "\nSome accounting program opens but it's not"
			print "what you need so you close it."
			custom_error.errortype(4)
		elif computer_prompt == 3:
			print "\nYou see files on bunch of employees. Nothing of interest here."
			custom_error.errortype(4)
		elif computer_prompt == 0:
			print "You log out of computer."
			computer = False
			return 'Motor Shop'
		else:
			custom_error.errortype(3)

def enter(the_player):

	the_player.location = 'Motor Shop'
	the_player.directions = ['Curling Street', 'left door', 'right door']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "You're back at the shop."


	else:
		the_player.visited.append(the_player.location)

		print "Thankfully the doors were not locked but"
		print "just in case you block them with a nearby"
		print "table."
		print "There's no light here so you turn on your"
		print "flashlight to look around."
		print "\nYou see mostly fishing stuff and some raided"
		print "supplies. There is a counter close to the wall"
		print "and two doors, one on the left and one on the right."

	while True:
		print "There is a counter in front of you and two doors,"
		print "one on the left and other on the right."

		action = prompt.standard(the_player)

		if action == "curling street" and 'motor' not in the_player.inventory.keys():
			print "\nYou still haven't found the motor."
			print "It's too risky to leave now and return later"
			print "because of the zombie herd outside."
		elif action == "curling street" and 'cart' not in the_player.inventory.keys():
			print "\nYou still need something to put the motor in. It is"
			print "too heavy to carry it in hands. The Junction if kind of"
			print "far too."
		elif action == "curling street" and 'cart' and 'motor' in the_player.inventory.keys():
			print "\nYou put the motor in the cart and head out of Motor shop to"
			print "meet Wanda at Junction."
			the_player.visited.append('got the motor')
			print "Thankfully the zombie herd is on the other"
			print "side of the street, on the spot where"
			print "Wanda taunted it. You don't see her"
			print "so you head out to Junction..."

			custom_error.errortype(4)
			
			if 'got the motor' and 'Wanda' in the_player.visited:
				print "Wanda: 'You made it! Great. I see you got pretty"
				print "creative with that cart.'"

			if 'boat key' in the_player.inventory.keys():
				print "Well, we have the key and the motor so let's"
				print "go to Harrington River, it's not far."
			else:
				print "We still need that boat key. It's in the"
			
				print "lobby of Old Building on March Street."
			return 'Junction'
		elif 'left' in action:
			return 'Warehouse'
		elif 'right' in action:
			return 'Maintenance room'
		elif 'counter' in action:
			print "There are some papers scattered around with"
			print "dried blood on them."
			print "You see a closed laptop."
		elif 'laptop' in action:
			print "You open the laptop and to your surprise"
			print "it powers up."
			laptop(the_player)
		else:
			custom_error.errortype(3)





import prompt
import score

def enter(the_player):

	the_player.location = 'Apartment'
	the_player.directions = ['Curling Street']

	print "\nLocation: ", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "You've been here already. It's your old"
		print "apartment."

	elif not the_player.location in the_player.visited:
		the_player.visited.append(the_player.location)
		print "You wake up at your old apartment."
		print "All the food and water is gone"
		print "and you know you've been postponing"
		print "your leave."
		print "The cupboard in the kitchen seems empty."
		print "You can go out to %s." % the_player.directions[0]

	else:
		pass


	while True:
		action = prompt.standard(the_player)

		if action == 'curling street' and not the_player.directions[0] in the_player.visited:
			print "You take courage and step out of your apartment."
			score.calculate(the_player, 'out of the house')
			break

		elif action == 'curling street' and the_player.directions[0] in the_player.visited:
			break

		elif action == 'cupboard' and not 'chocolate bar' in the_player.inventory.keys():
			print "You take a look once again, scanning"
			print "through empty packaging..."
			print "You find a chocolate bar!"

			the_player.inventory['chocolate bar'] = 1
			score.calculate(the_player, 'chocolate bar')

		elif action == 'cupboard':
			print "You search cupboard again but it's empty."

		else:
			pass

	return 'Curling Street'


	


import prompt
import custom_error
import death

def enter(the_player):

	the_player.location = 'Wanda\'s house'

	if 'Wanda' in the_player.visited:
		the_player.directions = ['Wanda\'s house street']
	else:
		the_player.directions = ['Street with large mansion']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:

		print "You've come back to %s." % the_player.location
		print "Alfie greets you by jumping at you."

	else:
		the_player.visited.append(the_player.location)

		print "The door were not locked but as soon"
		print "as you got inside you see the dog"
		print "that was making all the noise."
		print "The dog is a large dachshund with"
		print "really threatening look."
		print "It's growling at you..."

		custom_error.errortype(4)

		print "Suddenly you hear 'Alfie!' and"
		print "the dog runs up the wooden stairs."
		print "There you see a young woman aiming"
		print "small revolver at you."
		print "She says: 'Now I'm going"
		print "to ask you some questions and you're'"
		print "gonna answer.'"

		custom_error.errortype(4)

		end_conversation = False

		while end_conversation == False:

			print "'Are you gonna hurt me?'"
			print "1. Yes"
			print "2. No\n"

			answer_hurt = prompt.conversation()

			if answer_hurt == 1:
				death.type(10,the_player)
			elif answer_hurt == 2:
				print "'Good, good."
				print "Why did you come here?'"

				while end_conversation == False:
					print "1. I was looking for a shelter."
					print "2. I heard the dog barking."
					print "3. I need to get out of this town.\n"

					answer_come = prompt.conversation()

					if answer_come == 2:
						print "'Hmm. Alfie's been tense lately'"
						print "and this is exactly what I was worried"
						print "about. That the barking would attract more"
						print "deads or not-so-friendly types.'\n"

						pass

					elif answer_come == 1:
						print "Well... you can't expect me to offer you"
						print "a place to crash. You're a stranger!\n"

						pass

					elif answer_come == 3:
						end_conversation = True

			else:
				custom_error.errortype(1)

		print "'Well.. that makes two of us... name's Wanda by the way.'"
		print "'%s' you say." % the_player.name
		print "'Nice to meet you.'"

		custom_error.errortype(4)

		print "'Listen, I have a plan, sort of. Me and my boyfriend"
		print "were staying at this building on March St. We were"
		print "preparing to get outta town."
		print "We had everything - supplies, ammo and a ride..."
		print "but then a horde of deads heard us and started to"
		print "crawl into the lobby.'"

		custom_error.errortype(4)

		print "Well I managed to escape and still.. a herd of them"
		print "were following me for days. Then I found this place"
		print "and I have been here since."
		print "I couldn't get back... I was so scared and I'm not sure"
		print "I'll even see Dave again..."

		if 'Dave is dead' in the_player.visited:

			print "You: 'Listen, Wanda..'"
			print "'I know what happened to Dave.'"
			print "Wanda: 'You saw him?!'"
			print "'Yeah.. he turned, I had to kill him,' you replied."
			print "Wanda explodes in tears, you try to comfort her"
			print "but it's useless"

			custom_error.errortype(4)

			print "Few hours later she calms down a bit."
			print "'Hey.. I can't stay here. I gotta get away."
			print "let's get back to what I was trying to say...'"

		else:
			pass

		print "\n'The really bad thing is we had a perfect way out."
		print "We managed to fix one of the boats on Harrington River"
		print "but it had a broken motor.'"
		print "\n'So we got found a new one in a shop on Curling Street.'"
		print "You: 'Yeah that's where my place is.'"
		print "'Cool. But it gets worse. The keys for the boat"
		print "are somewhere in the building on March St., the place"
		print "where I saw Dave for last time.'"

		custom_error.errortype(4)

		print "'There should be a trunk with lock on it, I have the"
		print "password.'"
		print "\n'Let's get the motor and the key and get out of this"
		print "hellhole."
		print "We'll get going tomorrow morning.'"

		custom_error.errortype(4)

		hp_to_heal = the_player.max_hitpoints - the_player.hitpoints
		the_player.hitpoints = the_player.hitpoints + hp_to_heal
		print "You gain %.1f hitpoints from good night sleep.\n" % hp_to_heal


		print "'Hey %s here you go. It's a bandage that'll" % the_player.name
		print "heal you but it takes time to apply so you"
		print "need to use it outside of battle.'"
		print "\n*** Type HEAL outside of battle to heal yourself. ***\n"

		the_player.inventory['bandage'] = 2

		print "You get %d bandages." % the_player.inventory['bandage']
		print "Let's go! Alfie you need to stay here for now."

		the_player.visited.append('Wanda')


	while True:
		action = prompt.standard(the_player)

		if action == "street with large mansion" or 'out' in action or 'street' in action:
			return 'Cherry trees'
		else:
			custom_error.errortype(3)




def location(current_location):

	hints = {
	'Apartment': 'Try searching the cupboard.',
	'Curling Street': 'Notice the policeman.',
	'Foreman Ave': 'Check the waste containers.',
	'Harrington River': 'no hint',
	'March Street': 'Maybe there\'s something in the building.',
	'Junction': 'You need to decide where to go.',
	'Old Building': 'Try getting the lights on somehow.',
	'Old Building (first floor)': 'Dave might have something delicious on him.',
	'Old Building (second floor)': 'Get something good for Charlie, he will return the favor.',
	'22nd Street': 'Sometimes monsters are here, sometimes not.',
	'Wanda\'s House': 'Type OUT to go out.',
	'Suburbs':'Look for the pirate flag and listen to dog bark.',
	'Suburb 1': 'Nothing here...',
	'Suburb 2': 'Nothing here...',
	'Suburb 3': 'Nothing here...',
	'Suburb 4': 'Check the pirate flag.',
	'Suburb 5': 'Nothing here...',
	'Suburb 6': 'Nothing here...',
	'Suburb Junction': 'Go check the mansion.',
	'Small houses': 'Nothing here...',
	'House with pirate flag': 'Take the stairs, also there might be something in the kitchen.',
	'Basement': 'You need to look through junk several times, there are 2 items.',
	'Kitchen': 'Look in the cupboard.',
	'Cherry trees': 'Go check out the mansion.',
	'A very long street': 'Nothing here...',
	'Motor Shop': 'There is a laptop on the counter. Look for item K5-22TS.',
	'Warehouse': 'Check the shelves A and T.',
	'Maintenance room': 'You need three items to use the workbench, they\'re all here in the building.',
	'Restroom': 'You might wanna take the broom.',
	'Marina': 'Yellow boat is Wanda\'s boat. Careful when going inside.',
	'22nd Street': 'Always save before going in this location, lots of enemies around.',
	}

	return hints.get(current_location)



import sys
import random
import prompt
import custom_error
import score
import fight
import death

def enter(the_player):
	the_player.location = 'Curling Street'
	the_player.directions = ['Apartment','Junction']

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited and 'charlie sleepover' in the_player.visited and 'Wanda' in the_player.visited:
		print "\nThe whole Curling St. is swarmed with a herd of zombies."
		print "Wanda: 'Tss.. be careful."
		print "Here's the plan: I'm gonna sneak onto other side"
		print "and distract them."
		print "Meanwhile get in the shop and look for the motor - it should"
		print "have label 'K5-22TS' on it. It's pretty heavy so you might need"
		print "something to move it around."
		print "We'll meet back at Junction once you're done but be quick!'"

		score.calculate(the_player,'wanda decoy')
		
		print "\nWanda sneaks behind the cars and gets about 30m away from you."
		print "'Come on, you fuckers!' she screams. The herd starts moving towards"
		print "her. You hope she'll be fine."
		print "'B&D Motors' is ahead, you carefully sneak into the shop..."

		custom_error.errortype(4)

		return 'Motor Shop'

	elif the_player.location in the_player.visited and 'charlie sleepover' in the_player.visited:
		print "You try to step carefully, hiding behind close by dumpster."
		print "Unfortunately you step on broken glass and the"
		print "swarm starts to navigate towards you..."

		custom_error.errortype(4)

		while True:
			encounter = fight.Encounter(the_player, 'zombie male')
			encounter.start(the_player)
			print "As you finished one zombie, another one approaches."
			print "Time to get ready..."

			custom_error.errortype(4)

	elif 'motor' in the_player.inventory.keys() and 'Wanda' in the_player.visited:
		print "Wanda: 'We already got what we need, let's just go"
		print "the herd might move back here again.'"
		return 'Junction'

	elif the_player.location in the_player.visited:

		if 'gun' in the_player.inventory.keys():
			pass		

		else:
			print "There is still a policeman lying on the floor."
			pass
	
		print "You're in %s again." % the_player.location
		print "You've been here before."

		pass		
	
	else:

		the_player.visited.append(the_player.location)

		print "You walk out of your apartment."
		print "You are on %s, it's a large street" % the_player.location
		print "with junction at the end."
		print "There are corpses everywhere, all of them"
		print "are dead and didn't turn."
		print "Most of them probably commited suicide."
		print "You notice a corpse of policeman few meters from you."
	
	while True:
		if the_player.hitpoints <= 0:
			death.type(3, the_player)
		else:
			pass

		action = prompt.standard(the_player)

		if action == "apartment":
			return the_player.directions[0]
			break
		elif action == "policeman" and not 'gun' in the_player.inventory.keys():
			bullets = random.randint(5,10)
			the_player.inventory['gun'] = bullets
			print "You take the gun which has %d bullets in it." % bullets
			get_score = score.calculate(the_player, 'gun')
		elif action == "policeman":
			print "You already searched the policeman."
		elif action == "junction":
			return 'Junction'
		else:
			custom_error.errortype(3)

	


import random
import prompt
import score
import death
import fight
import custom_error

def container(the_player):

	containers = range(1,8)
	right_container = random.choice(containers)

	print "You go closer to the containers. There are"
	print "%d of them, all green. Which one do you want" % len(containers)
	print "to look at?"

	tries = 0
	right_tries = 0

	while True:
		
		try:
			print "Number (%d - %d), '0' to exit > " % (containers[0],containers[-1])
			choice = int(raw_input("> "))

			if choice in containers:
				if choice == right_container and right_tries == 2 and 'foreman knife' not in the_player.visited:
					print "You find a knife!"
					the_player.inventory['knife'] = 15
					score.calculate(the_player,'knife')
					the_player.visited.append('foreman knife')
				elif choice == right_container and right_tries == 0:
					print "Hmm.. maybe you need to look further."
					right_tries = right_tries + 1
				elif tries == 0:
					tries = tries + 1
					print "Hmm.. maybe you need to look further."
				elif choice == right_container and right_tries == 1:
					print "You need to go deeper..."
					right_tries = right_tries + 1
				elif tries == 1:
					print "You need to go deeper..."
					tries = tries + 1
				elif tries == 2:
					print "You find nothing."
					tries = 0
			elif choice == 0:
				break
			else:
				print "That container does not exist."
		except ValueError:
			print "Put down numbers only."

def enter(the_player):

	the_player.location = 'Foreman Ave'
	the_player.directions = ['Junction','Commercial Building', 'Car barricade']
	glass = random.randint(1,4)

	print "\nLocation:", the_player.location
	print "-" * 30

	if the_player.location in the_player.visited:
		print "You're back at %s." % the_player.location
		print "There are waste containers on the side"
		print "of the road."
		print "Building with broken shop window is next to them."

	else:
		the_player.visited.append(the_player.location)

		print "You come to wide street with various shops"
		print "on each side and garbage everywhere."
		print "There are seven green waste containers on the right"
		print "side of the road that are stuffed"
		print "with various things."
		print "You see a commercial building, probably a shop"
		print "with broken front shop window."
		print "The street ends with a huge barricade made out of"
		print "cars."

	while True:

		action = prompt.standard(the_player)

		if action == "junction":
			return 'Junction'
		elif 'waste' in action or 'container' in action:
			container(the_player)
		elif 'window' in action or 'commercial' in action or 'building' in action:
			if glass == 1:
				death.type(12,the_player)
			else:
				print "You lose balance while stepping to the shop,"
				print "you almost impale yourself on glass shrapnel."
				print "Don't try that again!"
				score.calculate(the_player,'glass')
		elif 'cars' in action or 'barricade' in action or 'car' in action:

			print "You try to climb the car barricade but"
			print "you fail, falling to the ground."
	
			if 'car barricade' not in the_player.visited:
				encounter = fight.Encounter(the_player,'random')
				print "Somehow, a zombie crawls from one of the cars."
				
				custom_error.errortype(4)
				encounter.start(the_player)
				the_player.visited.append('car barricade')
			else:
				pass
		else:
			custom_error.errortype(3)


